@@ -2,7 +2,7 @@
 /*****************************************************************************
  * 
  * Usepackage Environment Manager
- * Copyright (C) 1995-2005  Jonathan Hogg  <jonathan@onegoodidea.com>
+ * Copyright (C) 1995-2015  Jonathan Hogg  <me@jonathanhogg.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
  * Name   : package.h
- * Author : Jonathan Hogg <jonathan@onegoodidea.com>
+ * Author : Jonathan Hogg <me@jonathanhogg.com>
  * 
  ****************************************************************************/
 
@@ -52,11 +52,14 @@
 #define VAR_PATH_ADD 2
 #define VAR_PATH_TESTSET 3
 #define VAR_PATH_TESTADD 4
+#define VAR_PATH_APPEND 5
 
 #define MATCH_EXACT 0
 #define MATCH_PREFIX 1
 #define MATCH_WILD 2
 
+#define INCLUDE_STACK_DEPTH 10
+
 #define DEBUG if (debugging) fprintf
 #define new(x) ((x*)malloc(sizeof(x)))
 
@@ -73,6 +76,7 @@ typedef struct {
    linked_list* variables;
    linked_list* requires;
    linked_list* scripts;
+   linked_list* aliases;
 } package_t;
 
 typedef struct {
@@ -101,6 +105,11 @@ typedef struct {
    char* text;
 } script_t;
 
+typedef struct {
+   char* name;
+   char* text;
+} alias_t;
+
 /*** globals: ***/
 
 extern int debugging;
