@@ -2,7 +2,7 @@
 /*****************************************************************************
  * 
  * Usepackage Environment Manager
- * Copyright (C) 1995-2005  Jonathan Hogg  <jonathan@onegoodidea.com>
+ * Copyright (C) 1995-2015  Jonathan Hogg  <me@jonathanhogg.com>
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * 
  * Name   : utils.c
- * Author : Jonathan Hogg <jonathan@onegoodidea.com>
+ * Author : Jonathan Hogg <me@jonathanhogg.com>
  * 
  ****************************************************************************/
 
@@ -35,6 +35,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <unistd.h>
+#include <sys/types.h>
 #include "utils.h"
 
 
